<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns="http://www.filemaker.com/fmpxmlresult" xmlns:bf="http://www.chapsoft.com/brushfire/summary" exclude-result-prefixes="bf">
    <xsl:output encoding="UTF-8" method="xml" version="1.0"/>
    
    
    <!-- 	Stylesheet written by Russell Kohn
		Chaparral Software & Consulting Services, Inc. 
		www.chapsoft.com  
		
		version 1.0
		May 24, 2004
	-->
    <!-- namespaces used in this stylesheet are:
	
		xsl = standard xslt namespace from w3
		bf = Brushfire grammar
		<none> = FileMaker Pro 6 grammar (FMPXMLRESULT)  
		   
            -->
    <!-- VARIABLES -->
    <!-- recCount : count of records in import file -->
    <xsl:variable name="recCount" select="count(/bf:brushfire_summary/bf:file)"/>
    <xsl:template match="/">
        <FMPXMLRESULT xmlns="http://www.filemaker.com/fmpxmlresult">
            <ERRORCODE>0</ERRORCODE>
            <PRODUCT BUILD="" NAME="" VERSION=""/>
            <DATABASE DATEFORMAT="M/d/yyyy" LAYOUT="" NAME="" TIMEFORMAT="h:mm:ss a">
                <xsl:attribute name="RECORDS">
                    <xsl:value-of select="$recCount"/>
                </xsl:attribute>
            </DATABASE>
            <METADATA>
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="Client" TYPE="TEXT" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="Project" TYPE="TEXT" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="Programmer" TYPE="TEXT" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="Comments" TYPE="TEXT" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="Version" TYPE="TEXT" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="ReportDate" TYPE="DATE" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="FileCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="ScriptCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="ScriptStepCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="FieldCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="RelationCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="LayoutCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="FieldOnLayoutCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="BFEngineVersion" TYPE="TEXT" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="Duration" TYPE="TEXT" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_ID" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_Name" TYPE="TEXT" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_ErrorCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_WarningCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_ObsoleteCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_DependencyFileCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_DependencyReferenceCount" TYPE="NUMBER" />		
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_FieldCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_ScriptCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_RelationCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_LayoutCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_ScriptStepCount" TYPE="NUMBER" />
				<FIELD EMPTYOK="YES" MAXREPEAT="1" NAME="File_FieldOnLayoutCount" TYPE="NUMBER" />
			</METADATA>
            
            <RESULTSET>
                <xsl:attribute name="FOUND">
                    <xsl:value-of select="$recCount"/>
                </xsl:attribute>
                <xsl:call-template name="import_BFSummary"/>
            </RESULTSET>
        </FMPXMLRESULT>
    </xsl:template>
    
    
    <xsl:template name="import_BFSummary">
        <xsl:for-each select="*/bf:file">
            <ROW>
                <xsl:attribute name="MODID">0</xsl:attribute>
                <xsl:attribute name="RECORDID">0</xsl:attribute>
                
                
                <!-- projectinfo -->
                <xsl:for-each select="../bf:projectinfo/*">
                	<COL><DATA>
                		<xsl:value-of select="."/>
                	</DATA></COL>
                </xsl:for-each>
               
               
                <!-- analysissummary -->
                <xsl:for-each select="../bf:analysissummary/*">
                	<COL><DATA>
                		<xsl:value-of select="."/>
                	</DATA></COL>
                </xsl:for-each>
                
                
                
                <!-- bfid is a Brushfire Engine created unique ID -->
             	 <COL><DATA>
             		 <xsl:value-of select="@bfid"/>
             	 </DATA></COL>
             	 
             	 
             	 <!-- file name -->
             	 <COL><DATA>
             	 	<xsl:value-of select="@name"/>
             	 </DATA></COL>
                
                
                <!-- file analysis -->
                <xsl:for-each select="bf:analysis/*">
                	<COL><DATA>
                		<xsl:value-of select="."/>
                	</DATA></COL>
                </xsl:for-each>
                
                <!-- file structure -->
                <xsl:for-each select="bf:structure/*">
                	<COL><DATA>
                		<xsl:value-of select="."/>
                	</DATA></COL>
                </xsl:for-each>
                
                
                
            </ROW>
        </xsl:for-each>
    </xsl:template>

    
    
</xsl:stylesheet>
